;;;;;;;;;;;;;;;;;;;;;;; Rectangl.LSP ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;;;   (C) Copyright 1995 by Leonard R. Miller.
;;;       Rt 4 Box 183b, Camden, Ar, 71701
;;;       Compuserve 74216,2346
;;;
;;;   I provide this program "as is" and with all faults.  I do not
;;;   warrant its operation to be error free.
;;;
;;; Permission to use, copy, modify, and distribute this software
;;; for any non-commerial, non-profit purpose and without fee is
;;; hereby granted, provided that the above copyright notice appears
;;; in all copies and that both the above copyright notice and this
;;; permission notice also appear in all supporting documentation.
;;;
;;;
;;; Draw rectangle with user's choice of location, rotation, and
;;;  nine different justifications (similar to DTEXT).
;;;  Finally, allow choice of linetype, standard or polyline.
;;;  User entry is automated for speed.
;;;
(defun c:rectangl (/ entry lupr pt0 pt1 pt2 pt3 pt4 rect_ctr
                   loc_pt orig_x orig_y target_x target_y)
;;
;;;
;;; Some AutoCAD users - and I'm one of them - draw in either
;;;  U.S. or metric units.  For that reason I set a global variable
;;;  - US_MM - to either 1.0 (for inches) or 25.4 (for metric).  This
;;;  helps to automate certain drawing tasks.  It's not, however,
;;;  required.  The next statement will test for the contents of that
;;;  variable and if it's not set will assume U.S. units.  
;;;
(if (= us_mm nil)
  (setq us_mm 1.0)
  )
;;;
;;
(setq lupr (getvar "luprec"))
(setq entry nil)
(if (= width_size nil)(setq width_size (* us_mm 1.0)))
(setq entry (getdist
 (strcat "\nHoriz. length - Pick or Enter ...<" (rtos width_size 2 lupr) ">: ")))
	(if (/= entry nil)(setq width_size entry)
	);end if 
;;
(setq entry nil)
(if (= height_size nil)(setq height_size width_size))
(setq entry (getdist
 (strcat "\nVert. length - Pick or Enter ...<" (rtos height_size 2 lupr) ">: ")))
	(if (/= entry nil)(setq height_size entry)
	);end if 
;;
(setq entry nil)
(setq rect_ctr (getpoint "\nPlace it where? ..."))
(if (= just_pt nil)
  (setq just_pt "M")
);endif
(initget "L M R TL TC TR BL BC BR")
(setq entry (getkword (strcat
	"\nJustify - [M]id, [L]eft,[R],TL,TC,TR,BL,BC, or BR? <"
	 just_pt ">")))
(if (/= entry nil)
	(setq just_pt entry)
)
;;;
(setq pt0 (polar rect_ctr pi (/ width_size 2)))
(setq pt1 (polar pt0 (* pi 1.5) (/ height_size 2)))
(setq pt2 (polar pt1 0.0 width_size))
(setq pt3 (polar pt2 (* pi 0.5) height_size))
(setq pt4 (polar pt3 pi width_size))
(command "pline" pt1 pt2 pt3 pt4 "c")
;;
(setq orig_x (car rect_ctr))
(setq orig_y (cadr rect_ctr))
;;;
;move to middle
(if (= just_pt "M")
 (progn
  (setq target_x (+ orig_x 0.0))
  (setq target_y (+ orig_y 0.0))
 )
)
;;;
;move to top right
(if (= just_pt "TR")
 (progn
  (setq target_x (- orig_x (/ width_size 2)))
  (setq target_y (- orig_y (/ height_size 2)))
 )
)
;;;
;move to top left
(if (= just_pt "TL")
 (progn
  (setq target_x (+ orig_x (/ width_size 2)))
  (setq target_y (- orig_y (/ height_size 2)))
 )
)
;;;
;move to bottom left
(if (= just_pt "BL")
 (progn
  (setq target_x (+ orig_x (/ width_size 2)))
  (setq target_y (+ orig_y (/ height_size 2)))
 )
)
;;;
;move to bottom right
(if (= just_pt "BR")
 (progn
  (setq target_x (- orig_x (/ width_size 2)))
  (setq target_y (+ orig_y (/ height_size 2)))
 )
)
;;;
;move to left
(if (= just_pt "L")
 (progn
  (setq target_x (+ orig_x (/ width_size 2)))
  (setq target_y (+ orig_y 0.0))
 )
)
;;;
;move to right
(if (= just_pt "R")
 (progn
  (setq target_x (- orig_x (/ width_size 2)))
  (setq target_y (+ orig_y 0.0))
 )
)
;;;
;move to top center
(if (= just_pt "TC")
 (progn
  (setq target_x (+ orig_x 0.0))
  (setq target_y (- orig_y (/ height_size 2)))
 )
)
;;;
;move to bottom center
(if (= just_pt "BC")
 (progn
  (setq target_x (+ orig_x 0.0))
  (setq target_y (+ orig_y (/ height_size 2)))
 )
)
;;;
;;;
(setq loc_pt (list target_x target_y))
(command "move" "l" "" rect_ctr loc_pt)
;;;
(princ "\nAnd it's angle? ...")
(command "rotate" "l" "" rect_ctr "r" rect_ctr pt0 pause)
;;;
;;;
(setq entry nil)
(if (= line_style nil)
	(setq line_style "P")
)
(initget "P R Q")
(setq entry (getkword (strcat
	"\n[P]olyline or [R]egular linetype? <" line_style ">")))
(if (/= entry nil)
	(setq line_style entry)
)
(if (= line_style "R")
	(command "explode" "l")
)
(command)(princ)
)